==> Data-Conveyor-1.100870.tar.gz: Data-Conveyor-1.100870/lib/Data/Conveyor/Ticket/Payload/Instruction/Container_TEST.pm <==
use 5.008;
use strict;
use warnings;

package Data::Conveyor::Ticket::Payload::Instruction::Container_TEST;
our $VERSION = '1.100870';
# ABSTRACT: Stage-based conveyor-belt-like ticket handling system

use Test::More;
use parent 'Data::Conveyor::Test';
use constant PLAN => 1;

sub gen_filled_container {
    my ($self, @instruction_specs) = @_;
    my $container = $self->delegate->make_obj('payload_instruction_container');
    our $factory ||= $self->delegate->make_obj('payload_instruction_factory');
    for my $spec (@instruction_specs) {
        my ($command, $type, $value) = @$spec;
        $container->items_push(
            $factory->gen_instruction(
                $type,
                command => $self->delegate->$command,
                value   => $value
            )
        );
    }
    $container;
}

sub run {
    my $self = shift;
    $self->SUPER::run(@_);
    pass('dummy test to keep class tests happy');
}
1;


__END__
=pod

=head1 NAME

Data::Conveyor::Ticket::Payload::Instruction::Container_TEST - Stage-based conveyor-belt-like ticket handling system

=head1 VERSION

version 1.100870

=head1 METHODS

=head2 gen_filled_container

FIXME

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Data-Conveyor/>.

The development version lives at
L<http://github.com/hanekomu/Data-Conveyor/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHORS

  Marcel Gruenauer <marcel@cpan.org>
  Florian Helmberger <fh@univie.ac.at>
  Achim Adam <ac@univie.ac.at>
  Mark Hofstetter <mh@univie.ac.at>
  Heinz Ekker <ek@univie.ac.at>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Data-Conveyor-1.101690.tar.gz: Data-Conveyor-1.101690/lib/Data/Conveyor/Ticket/Payload/Instruction/Container_TEST.pm <==
use 5.008;
use strict;
use warnings;

package Data::Conveyor::Ticket::Payload::Instruction::Container_TEST;
BEGIN {
  $Data::Conveyor::Ticket::Payload::Instruction::Container_TEST::VERSION = '1.101690';
}
# ABSTRACT: Stage-based conveyor-belt-like ticket handling system

use Test::More;
use parent 'Data::Conveyor::Test';
use constant PLAN => 1;

sub gen_filled_container {
    my ($self, @instruction_specs) = @_;
    my $container = $self->delegate->make_obj('payload_instruction_container');
    our $factory ||= $self->delegate->make_obj('payload_instruction_factory');
    for my $spec (@instruction_specs) {
        my ($command, $type, $value) = @$spec;
        $container->items_push(
            $factory->gen_instruction(
                $type,
                command => $self->delegate->$command,
                value   => $value
            )
        );
    }
    $container;
}

sub run {
    my $self = shift;
    $self->SUPER::run(@_);
    pass('dummy test to keep class tests happy');
}
1;


__END__
=pod

=head1 NAME

Data::Conveyor::Ticket::Payload::Instruction::Container_TEST - Stage-based conveyor-belt-like ticket handling system

=head1 VERSION

version 1.101690

=head1 METHODS

=head2 gen_filled_container

FIXME

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Data-Conveyor/>.

The development version lives at
L<http://github.com/hanekomu/Data-Conveyor/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHORS

  Marcel Gruenauer <marcel@cpan.org>
  Florian Helmberger <fh@univie.ac.at>
  Achim Adam <ac@univie.ac.at>
  Mark Hofstetter <mh@univie.ac.at>
  Heinz Ekker <ek@univie.ac.at>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
